generate_feedback_plots: Generate plots for feedback reports to organisations

Description Usage Details Examples

View source: R/org-report-plots.R

Description

generate_feedback_plots This function generates the graphs that are to be used in the feedback reports to organisations following the completion of the 2020 Hunt Challenge.

Usage

1
generate_feedback_plots(instance_name)

Details

The graphs will be generated as images in the 'exports' folder in your R working directory. The images then need to be manually inserted into the report template, which is a Google Doc. The template is called 'Organisation Feedback Template' and is stored in the drive under: SWARM2_ALL > Hunt Challenge 2020 > Reports to Organisations

Examples

1
2
3
4
5
## Not run: 
# (re-)compile data
generate_feedback_plots('2020_HuntChallenge')

## End(Not run)

Hunt-Laboratory/huntr documentation built on Sept. 27, 2020, 3:17 a.m.